@@ -48,22 +48,35 @@ class CLIContext(TransformAuth):
         return False
 
     def identify(self) -> None:  # noqa: D
-        msg = f"You are authenticated as {self.user_state.user.user_name} within the {self.user_state.organization.name} organization"
+        click.echo(
+            f"You are authenticated as {self.user_state.user.user_name} within the {self.user_state.organization.name} organization."
+        )
+        click.echo(self.mql_server_url_status)
 
         if self.user_state.current_model:
-            msg = (
-                msg
-                + f" using model at {self.user_state.current_model.repository}/{self.user_state.current_model.branch}:{self.user_state.current_model.commit}\n"
-                + self.mql_server_url_status
+            click.echo(
+                f"Your primary model is model id {self.user_state.current_model.id},"
+                + f" located at {self.user_state.current_model.repository}/"
+                + f"{self.user_state.current_model.branch}:{self.user_state.current_model.commit}"
+                + f" and created {self.user_state.current_model.created_at}."
             )
         else:
-            msg = (
-                msg
-                + ". There are currently no metrics committed for your org, please see https://app.transformdata.io/install "
-                + "for instructions on how to commit your first Transform metrics."
+            click.echo(
+                "There are currently no metrics committed for your org, please see https://app.transformdata.io/install"
+                + " for instructions on how to commit your first Transform metrics."
             )
-
-        click.echo(msg)
+        pinned_id = self.pinned_model_id
+        if pinned_id is not None:
+            pinned_model = self.backend_client.get_model_key(pinned_id)
+            click.echo(
+                f"Your pinned model is model id {pinned_model.id},"
+                + f" located at {pinned_model.repository}/{pinned_model.branch}:{pinned_model.commit}"
+                + f" and created {pinned_model.created_at}."
+            )
+            click.echo("Queries and other CLI actions will use this pinned model, not the primary model.")
+            click.echo("If you'd like to remove the pinned model, run `mql unpin-model`")
+        else:
+            click.echo("You do not have a model pinned.")
 
     @property
     def api_key(self) -> Optional[str]:  # noqa: D
@@ -80,7 +93,7 @@ class CLIContext(TransformAuth):
     def remove_api_key_and_prompt_browser_login(self) -> None:
         """Remove API key from config and prompt browser login. Used when MFA is newly required for an org."""
         if self.config.get_config_value(API_KEY_CONFIG_KEY) is not None:
-            self.config.remove_config_value(API_KEY_CONFIG_KEY)
+            self.config.pop_config_value(API_KEY_CONFIG_KEY)
         self.prompt_auth0_login()
 
     @property
@@ -101,7 +114,7 @@ class CLIContext(TransformAuth):
     @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
         self.config.set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
-        self.config.remove_config_value(API_KEY_CONFIG_KEY)
+        self.config.pop_config_value(API_KEY_CONFIG_KEY)
         self.identify()
         self.__just_authenticated = True
         if self.bearer_token_expires_at is not None:
@@ -238,7 +251,7 @@ class CLIContext(TransformAuth):
     @pinned_model_id.setter
     def pinned_model_id(self, model_id: int) -> None:  # noqa: D
         if not model_id:
-            self.config.remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+            self.config.pop_config_value(PINNED_MODEL_ID_CONFIG_KEY)
 
         # fetch model row to ensure it's valid
         self.mql.get_model_key(model_id)
@@ -246,13 +259,15 @@ class CLIContext(TransformAuth):
 
     def unpin_model(self) -> None:  # noqa: D
         if self.pinned_model_id:
-            self.config.remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+            self.config.pop_config_value(PINNED_MODEL_ID_CONFIG_KEY)
 
     @property
     def current_model(self) -> Optional[ModelKey]:  # noqa: D
         return self.user_state.current_model
 
-    def resolve_query_model_key(self, config_dir: Optional[str] = None) -> Optional[ModelKey]:
+    def resolve_query_model_key(
+        self, config_dir: Optional[str] = None, force_commit: bool = True
+    ) -> Optional[ModelKey]:
         """Resolve which model key to use for a given query or materialization.
 
         * If the user has specified they want to read from a local config directory, we commit that
@@ -260,16 +275,15 @@ class CLIContext(TransformAuth):
         * Otherwise, we default to None so that the query server can resolve the proper model key for the org.
         """
         if config_dir:
-            last_config_path = self.cli_state.get_config_value(PREV_CONFIG_DIR_PATH)
-            last_config_modified = self.cli_state.get_config_value(PREV_CONFIG_DIR_MODIFIED)
-            last_config_model_id = self.cli_state.get_config_value(PREV_MODEL_ID)
+            last_config_path = self.cli_state.pop_config_value(PREV_CONFIG_DIR_PATH)
+            last_config_modified = self.cli_state.pop_config_value(PREV_CONFIG_DIR_MODIFIED)
+            last_config_model_id = self.cli_state.pop_config_value(PREV_MODEL_ID)
 
             current_config_path = str(Path(config_dir).resolve())
             current_config_modified = directory_last_edited(config_dir)
 
-            # TODO@jack Re-enable once bug tracked down or sufficiently mitigated.
             if (
-                False
+                not force_commit
                 and last_config_path is not None
                 and last_config_modified is not None
                 and last_config_model_id is not None
@@ -277,22 +291,32 @@ class CLIContext(TransformAuth):
                 and current_config_path == last_config_path
                 and last_config_modified == str(current_config_modified)
             ):
+                self.cli_state.set_config_value(PREV_MODEL_ID, last_config_model_id)
                 model_key = self.mql.get_model_key(int(last_config_model_id))
-                click.echo(f"Using local model id {last_config_model_id}, created {model_key.created_at}")
-                return model_key
+                click.echo(
+                    textwrap.dedent(
+                        f"""\
+                    No model file changes detected since the most recent local run {model_key.created_at}.
+                    Re-using model id {last_config_model_id} and skipping commit and validation steps.
+                    To force the creation of a new model, use flag --force-commit
+                    """
+                    )
+                )
 
-            spinner = Halo(text="Parsing and uploading local configs…", spinner="dots")
-            spinner.start()
-            model_key = self.mql.commit_configs(config_dir)
+                # f"Using local model id {last_config_model_id}, created {model_key.created_at}")
+            else:
+                spinner = Halo(text="Parsing and uploading local configs…", spinner="dots")
+                spinner.start()
+                model_key = self.mql.commit_configs(config_dir)
+                spinner.succeed("🌱 Successfully parsed local configs")
 
             self.cli_state.set_config_value(PREV_MODEL_ID, str(model_key.id))
             self.cli_state.set_config_value(PREV_CONFIG_DIR_PATH, current_config_path)
             if current_config_modified:
                 self.cli_state.set_config_value(PREV_CONFIG_DIR_MODIFIED, str(current_config_modified))
             else:
-                self.cli_state.remove_config_value(PREV_CONFIG_DIR_MODIFIED)
+                self.cli_state.pop_config_value(PREV_CONFIG_DIR_MODIFIED)
 
-            spinner.succeed("🌱 Successfully parsed local configs")
             return model_key
 
         if self.pinned_model_id:
